==> calligra-2.4.3.tar.xz: calligra-2.4.3/plugins/reporting/maps/KoReportMapsPlugin.h <==
/*
   Copyright (C) 2010 by Adam Pigg (adam@piggz.co.uk)
   Copyright (C) 2011 by Radoslaw Wicik (radoslaw@wicik.pl)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KOREPORTMAPSPLUGIN_H
#define KOREPORTMAPSPLUGIN_H

#include <KoReportPluginInterface.h>


class KoReportMapsPlugin : public KoReportPluginInterface
{
    public:
    KoReportMapsPlugin(QObject *parent, const QVariantList &args = QVariantList());
    virtual ~KoReportMapsPlugin();

    virtual QObject* createRendererInstance(QDomNode& element);
    virtual QObject* createDesignerInstance(QDomNode& element, KoReportDesigner* , QGraphicsScene* scene);
    virtual QObject* createDesignerInstance(KoReportDesigner* , QGraphicsScene* scene, const QPointF& pos);
    virtual QObject* createScriptInstance(KoReportItemBase* item);
};

#endif // KOREPORTMAPSPLUGIN_H

==> calligra_2.8.5+dfsg.orig.tar.xz: calligra-2.8.5+dfsg/plugins/reporting/maps/KoReportMapsPlugin.h <==
/*
   Copyright (C) 2010 by Adam Pigg (adam@piggz.co.uk)
   Copyright (C) 2011 by Radoslaw Wicik (radoslaw@wicik.pl)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KOREPORTMAPSPLUGIN_H
#define KOREPORTMAPSPLUGIN_H

#include <KoReportPluginInterface.h>


class KoReportMapsPlugin : public KoReportPluginInterface
{
    public:
    explicit KoReportMapsPlugin(QObject *parent, const QVariantList &args = QVariantList());
    virtual ~KoReportMapsPlugin();

    virtual QObject* createRendererInstance(QDomNode& element);
    virtual QObject* createDesignerInstance(QDomNode& element, KoReportDesigner* , QGraphicsScene* scene);
    virtual QObject* createDesignerInstance(KoReportDesigner* , QGraphicsScene* scene, const QPointF& pos);
    virtual QObject* createScriptInstance(KoReportItemBase* item);
};

#endif // KOREPORTMAPSPLUGIN_H
